@@ -255,6 +255,49 @@ class ClustersManager(object):
         else:
           logging.info('No instance group size changes needed.')
 
+        # Check if needs to update autoHealingPolicies.
+        auto_healing_policy = {}
+        # Check if needs to update health check URL in autoHealingPolicies.
+        old_url = instance_group_body.get('auto_healing_policy',
+                                          {}).get('health_check')
+        new_url = cluster.auto_healing_policy.get('health_check')
+
+        if new_url != old_url:
+          logging.info(
+              'Updating the health check URL in auto_healing_policy'
+              'of instance group %s from %s to %s.', resource_name, old_url,
+              new_url)
+          auto_healing_policy['healthCheck'] = new_url
+
+        # Check if needs to update initial delay in autoHealingPolicies.
+        old_delay = instance_group_body.get('auto_healing_policy',
+                                            {}).get('initial_delay_sec')
+        new_delay = cluster.auto_healing_policy.get('initial_delay_sec')
+
+        if new_delay != old_delay:
+          logging.info(
+              'Updating the health check initial delay in auto_healing_policy'
+              'of instance group %s from %s seconds to %s seconds.',
+              resource_name, old_delay, new_delay)
+          auto_healing_policy['initialDelaySec'] = new_delay
+
+        # Send one request to update either or both if needed
+        if auto_healing_policy:
+          if new_url is None or new_delay is None:
+            auto_healing_policy = {}
+            if new_url is not None or new_delay is not None:
+              logging.warning(
+                  'Deleting auto_healing_policy '
+                  'because its two values (health_check, initial_delay_sec) '
+                  'should never exist independently: (%s, %s)', new_url,
+                  new_delay)
+          try:
+            instance_group.patch_auto_healing_policies(
+                auto_healing_policy=auto_healing_policy,
+                wait_for_instances=False)
+          except bot_manager.OperationError as e:
+            logging.error('Failed to create instance group %s: %s',
+                          resource_name, str(e))
         return
 
     if template_needs_update:
@@ -268,6 +311,7 @@ class ClustersManager(object):
           resource_name,
           resource_name,
           size=cpu_count,
+          auto_healing_policy=cluster.auto_healing_policy,
           wait_for_instances=False)
     except bot_manager.OperationError as e:
       logging.error('Failed to create instance group %s: %s', resource_name,
@@ -524,6 +568,7 @@ class OssFuzzClustersManager(ClustersManager):
         cluster_info for cluster_info in project_info.clusters
         if cluster_info.cluster in existing_cluster_names
     ]
+    project_info.put()
 
   def update_project_cluster(self,
                              project,
